@@ -1,11 +1,12 @@
 /*
  * Javassist, a Java-bytecode translator toolkit.
- * Copyright (C) 1999-2007 Shigeru Chiba. All Rights Reserved.
+ * Copyright (C) 1999- Shigeru Chiba. All Rights Reserved.
  *
  * The contents of this file are subject to the Mozilla Public License Version
  * 1.1 (the "License"); you may not use this file except in compliance with
  * the License.  Alternatively, the contents of this file may be used under
- * the terms of the GNU Lesser General Public License Version 2.1 or later.
+ * the terms of the GNU Lesser General Public License Version 2.1 or later,
+ * or the Apache License Version 2.0.
  *
  * Software distributed under the License is distributed on an "AS IS" basis,
  * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
@@ -91,8 +92,15 @@ public abstract class CtBehavior extends CtMember {
     public abstract String getLongName();
 
     /**
-     * Returns the MethodInfo representing this method/constructor in the
+     * Returns the <code>MethodInfo</code> representing this method/constructor in the
      * class file.
+     *
+     * <p>If you modify the bytecode through the returned
+     * <code>MethodInfo</code> object, you might have to explicitly
+     * rebuild a stack map table.  Javassist does not automatically
+     * rebuild it for avoiding unnecessary rebuilding.
+     *
+     * @see javassist.bytecode.MethodInfo#rebuildStackMap(ClassPool)
      */
     public MethodInfo getMethodInfo() {
         declaringClass.checkModify();
@@ -100,7 +108,7 @@ public abstract class CtBehavior extends CtMember {
     }
 
     /**
-     * Returns the MethodInfo representing the method/constructor in the
+     * Returns the <code>MethodInfo</code> representing the method/constructor in the
      * class file (read only).
      * Normal applications do not need calling this method.  Use
      * <code>getMethodInfo()</code>.
@@ -145,6 +153,47 @@ public abstract class CtBehavior extends CtMember {
         methodInfo.setAccessFlags(AccessFlag.of(mod));
     }
 
+    /**
+     * Returns true if the class has the specified annotation class.
+     *
+     * @param clz the annotation class.
+     * @return <code>true</code> if the annotation is found,
+     *         otherwise <code>false</code>.
+     * @since 3.11
+     */
+    public boolean hasAnnotation(Class clz) {
+       MethodInfo mi = getMethodInfo2();
+       AnnotationsAttribute ainfo = (AnnotationsAttribute)
+                   mi.getAttribute(AnnotationsAttribute.invisibleTag);  
+       AnnotationsAttribute ainfo2 = (AnnotationsAttribute)
+                   mi.getAttribute(AnnotationsAttribute.visibleTag);  
+       return CtClassType.hasAnnotationType(clz,
+                                            getDeclaringClass().getClassPool(),
+                                            ainfo, ainfo2);
+    }
+
+    /**
+     * Returns the annotation if the class has the specified annotation class.
+     * For example, if an annotation <code>@Author</code> is associated
+     * with this method/constructor, an <code>Author</code> object is returned.
+     * The member values can be obtained by calling methods on
+     * the <code>Author</code> object.
+     *
+     * @param clz the annotation class.
+     * @return the annotation if found, otherwise <code>null</code>.
+     * @since 3.11
+     */
+    public Object getAnnotation(Class clz) throws ClassNotFoundException {
+       MethodInfo mi = getMethodInfo2();
+       AnnotationsAttribute ainfo = (AnnotationsAttribute)
+                   mi.getAttribute(AnnotationsAttribute.invisibleTag);  
+       AnnotationsAttribute ainfo2 = (AnnotationsAttribute)
+                   mi.getAttribute(AnnotationsAttribute.visibleTag);  
+       return CtClassType.getAnnotationType(clz,
+                                            getDeclaringClass().getClassPool(),
+                                            ainfo, ainfo2);
+    }
+
     /**
      * Returns the annotations associated with this method or constructor.
      *
@@ -586,6 +635,10 @@ public abstract class CtBehavior extends CtMember {
             StackMapTable smt = (StackMapTable)ca.getAttribute(StackMapTable.tag);
             if (smt != null)
                 smt.insertLocal(where, StackMapTable.typeTagOf(typeDesc), classInfo);
+
+            StackMap sm = (StackMap)ca.getAttribute(StackMap.tag);
+            if (sm != null)
+                sm.insertLocal(where, StackMapTable.typeTagOf(typeDesc), classInfo);
         }
     }
 
@@ -605,7 +658,15 @@ public abstract class CtBehavior extends CtMember {
     /**
      * Modifies the method/constructor body.
      *
+     * <p>While executing this method, only <code>replace()</code>
+     * in <code>Expr</code> is available for bytecode modification.
+     * Other methods such as <code>insertBefore()</code> may collapse
+     * the bytecode because the <code>ExprEditor</code> loses
+     * its current position.  
+     *
      * @param editor            specifies how to modify.
+     * @see javassist.expr.Expr#replace(String)
+     * @see #insertBefore(String)
      */
     public void instrument(ExprEditor editor)
         throws CannotCompileException
@@ -746,7 +807,7 @@ public abstract class CtBehavior extends CtMember {
             iterator.append(b.getExceptionTable(), gapPos);
 
             if (asFinally)
-                ca.getExceptionTable().add(0, gapPos, gapPos, 0);
+                ca.getExceptionTable().add(getStartPosOfBody(ca), gapPos, gapPos, 0); 
 
             int gapLen = iterator.getCodeLength() - gapPos - handlerLen;
             int subr = iterator.getCodeLength() - gapLen;
@@ -801,20 +862,30 @@ public abstract class CtBehavior extends CtMember {
         }
     }
 
+    /*
+     * assert subr > pos
+     */
     private void insertGoto(CodeIterator iterator, int subr, int pos)
         throws BadBytecode
     {
+        iterator.setMark(subr);
         // the gap length might be a multiple of 4.
-        boolean wide = subr + 4 - pos > Short.MAX_VALUE;
-        int gapSize = iterator.insertGap(pos, wide ? 4 : 2);
-
+        iterator.writeByte(Opcode.NOP, pos);
+        boolean wide = subr + 2 - pos > Short.MAX_VALUE;
+        pos = iterator.insertGapAt(pos, wide ? 4 : 2, false).position;
+        int offset = iterator.getMark() - pos;
         if (wide) {
             iterator.writeByte(Opcode.GOTO_W, pos);
-            iterator.write32bit(subr - pos + gapSize, pos + 1);
+            iterator.write32bit(offset, pos + 1);
+        }
+        else if (offset <= Short.MAX_VALUE) {
+            iterator.writeByte(Opcode.GOTO, pos);
+            iterator.write16bit(offset, pos + 1);
         }
         else {
-            iterator.writeByte(Opcode.GOTO, pos);
-            iterator.write16bit(subr - pos + gapSize, pos + 1);
+            pos = iterator.insertGapAt(pos, 2, false).position;
+            iterator.writeByte(Opcode.GOTO_W, pos);
+            iterator.write32bit(iterator.getMark() - pos, pos + 1);
         }
     }
 
@@ -1079,7 +1150,7 @@ public abstract class CtBehavior extends CtMember {
             if (stack > ca.getMaxStack())
                 ca.setMaxStack(stack);
 
-            iterator.insert(index, b.get());
+            index = iterator.insertAt(index, b.get());
             iterator.insert(b.getExceptionTable(), index);
             methodInfo.rebuildStackMapIf6(cc.getClassPool(), cc.getClassFile2());
             return lineNum;
