@@ -144,7 +144,7 @@ abstract public class AbstractTransformer implements ClassFileTransformer {
 			msg.append(e);
 			msg.append(" ");
 			msg.append(e.getStackTrace()[0]);
-			
+
 			handleException(e, msg.toString());
 			return null;
 
@@ -165,7 +165,7 @@ abstract public class AbstractTransformer implements ClassFileTransformer {
 		//log.error(e, msg);
 		//throw new IllegalClassFormatException(msg + " 原因:" + e);
 
-		log.debug(msg.toString());
+		log.debug(msg);
 	}
 
 	/**
@@ -173,8 +173,10 @@ abstract public class AbstractTransformer implements ClassFileTransformer {
 	 * <p>
 	 * @param fullPath フルパス
 	 * @param 追加対象の場合は true
+	 * @throws IOException 入出力例外が発生した場合
+	 * @throws NotFoundException クラスが見つからない場合
 	 */
-	protected boolean isClassPathTarget(String fullPath, String jarFileName) {
+	protected boolean isClassPathTarget(String fullPath, String jarFileName) throws IOException, NotFoundException {
 		return false;
 	}
 
@@ -186,7 +188,7 @@ abstract public class AbstractTransformer implements ClassFileTransformer {
 	 * @throws NotFoundException 指定されたパスが見つからない場合
 	 */
 	protected void addClassPath(String fullPath, String jarFileName) throws NotFoundException {
-		
+
 		appendedLocationPathSet.add(jarFileName);
 		String classPath = Files.decodeURL(fullPath);
 		classPool.appendClassPath(classPath);
@@ -228,6 +230,17 @@ abstract public class AbstractTransformer implements ClassFileTransformer {
 		return ctClass;
 	}
 
+	protected CtClass createCtClass(String className) throws IOException, NotFoundException {
+
+		long start = System.nanoTime();
+
+		CtClass ctClass = classPool.makeClass(className);
+		ctClass.detach();
+
+		Analyses.end(AbstractTransformer.class, "createCtClass", start);
+		return ctClass;
+	}
+
 	/**
 	 * 指定された CtClass オブジェクトが持つすべてのコンストラクタおよび
 	 * メソッド記述子をログに出力します。
