@@ -144,7 +144,7 @@ public class Metadata {
 
 		PropertySet p = new PropertySet(encodingPrefs);
 		String encoding = p.get("encoding");
-		log.debug("デフォルト自動設定のワークスペースエンコーディング: " + encoding);
+		log.debug("デフォルト自動設定のワークスペースエンコーディング: %s", encoding);
 		isNewWorkspace = false;
 		return encoding;
 	}
