@@ -21,7 +21,8 @@ import jp.sourceforge.mergedoc.pleiades.resource.PropertySet;
 @SuppressWarnings("serial")
 public class ConcurrentPropertySet extends PropertySet {
 
-	public ConcurrentPropertySet() {
+	public ConcurrentPropertySet(int initialCapacity) {
+		super(initialCapacity);
 	}
 
 	public ConcurrentPropertySet(File... files) {
