@@ -25,10 +25,11 @@ public class ValueHashPropertySet extends CachePropertySet {
 
 	/**
 	 * コンストラクタです。
+	 * @param initialCapacity 初期容量
 	 * @param comment プロパティー保存コメント
 	 */
-	public ValueHashPropertySet(String comment) {
-		super(comment);
+	public ValueHashPropertySet(int initialCapacity, String comment) {
+		super(initialCapacity, comment);
 	}
 
 	@Override
