@@ -23,6 +23,7 @@ import jp.sourceforge.mergedoc.pleiades.resource.PropertySet;
 
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.ArrayUtils;
+import org.apache.commons.lang.CharEncoding;
 
 /**
  * 複数のプロパティー・ファイルをマージし、1 つのプロパティー・ファイル
@@ -193,7 +194,7 @@ public class Generator {
 				for (File propFile : propFiles) {
 
 					PropertySet addProp = new PropertySet(propFile);
-					log.debug("Loaded " + propFile.getName() + " " + addProp.size());
+					log.debug("Loaded %s %d", propFile.getName(), addProp.size());
 
 					// % で始まる特殊プロパティを抽出し、別プロパティへ振り分け
 					for (Property p : addProp) {
@@ -332,8 +333,9 @@ public class Generator {
 	 * @param eplProp EPL プロパティー
 	 * @param nlsUiCustomRuleProp 校正＆ルール適用済み言語パック辞書プロパティー
 	 * @return マージ済み EPL プロパティー
+	 * @throws IOException 入出力k例外が発生した場合
 	 */
-	private PropertySet mergeEPL(PropertySet eplProp, PropertySet nlsUiCustomRuleProp) {
+	private PropertySet mergeEPL(PropertySet eplProp, PropertySet nlsUiCustomRuleProp) throws IOException {
 
 		PropertySet mergedProp = new PropertySet();
 		mergedProp.load(TEMP_NLS_HELP_CHECKED_PROP);	// ヘルプ未チェック辞書はマージしない
@@ -391,10 +393,16 @@ public class Generator {
 	 * (Ant からの呼び出しを終了させるため強制終了)
 	 * <p>
 	 * @param validator バリデーター
+	 * @throws IOException 入出力k例外が発生した場合
 	 */
-	private void exitIfValidationError(Validator validator) {
+	private void exitIfValidationError(Validator validator) throws IOException {
 
 		if (!validator.isSuccess()) {
+
+			File logFile = Files.getFile(validator.getLogFileName());
+			String s = FileUtils.readFileToString(logFile, CharEncoding.UTF_8);
+			log.info(s);
+
 			log.error("検証エラーのため、強制終了します。");
 			System.exit(-1);
 		}
@@ -428,6 +436,6 @@ public class Generator {
 			String line = Property.toString(key, prop.get(key));
 			lines.add(line);
 		}
-		FileUtils.writeLines(textFile, "UTF-8", lines);
+		FileUtils.writeLines(textFile, CharEncoding.UTF_8, lines);
 	}
 }
