@@ -365,5 +365,34 @@ public class TranslationDictionaryTest extends TestCase {
 		assertLookup("Line Feed ( ¶ )", "改行 ( ¶ )");
 		assertLookup("Convert Line Delimiters to Windows (CRLF, \\r\\n, 0D0A, \u00A4¶)",
 			"行区切り文字を Windows に変換 (CRLF, \\r\\n, 0D0A, \u00A4¶)");
+
+		// 全角混在
+		assertLookup("Space ( ・ )", "空白 ( ・ )");
+		assertLookup("Ideographic space ( ° )", "全角空白 ( ° )");
+		assertLookup("Tab ( ≫ )", "タブ ( ≫ )");
+		assertLookup("Carriage Return ( \u00a4 )", "復帰 ( \u00a4 )");
+		assertLookup("Line Feed ( ¶ )", "改行 ( ¶ )");
+		assertLookup("Convert Line Delimiters to Windows (CRLF, \\r\\n, 0D0A, \u00A4¶)",
+			"行区切り文字を Windows に変換 (CRLF, \\r\\n, 0D0A, \u00A4¶)");
+
+		//「参照 updates」になってしまう ⇒ 正規表現を修正
+		assertLookup("Browsing for updates", "更新の参照");
+		assertLookup("Browsing for xxx.xxx", "参照 xxx.xxx");
+		assertLookupFalse("Browsing for xxx");
+
+		// 辞書にエントリーがあっても末尾 . が 。 になる ⇒ ジェネレータの強制トリム廃止
+		assertLookup("Misc.", "その他");
+
+		// Tasks が翻訳されない ⇒ 正規表現を否定先読みに修正
+		assertLookup("Show Project Tasks", "プロジェクト・タスクの表示");
+		assertLookup("Show Project aaa", "プロジェクト aaa の表示");
+
+		// 正規表現取得は分割前 ⇒ 正規表現で記述する
+		assertLookup(
+				"Displays the configuration model of root project 'a'. [incubating]",
+				"ルート・プロジェクト 'a' の構成モデルを表示します。");
+		assertLookup(
+				"Displays the configuration model of root project 'a'.",
+				"ルート・プロジェクト 'a' の構成モデルを表示します。");
 	}
 }
